==> haskell-bytestring-show-0.3.5.6-29-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bytestring-show.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bytestring-show
version:              0.3.5.6
visibility:           public
id:                   bytestring-show-0.3.5.6-CyFJRb7BCGw1Zx32aGhpM8
key:                  bytestring-show-0.3.5.6-CyFJRb7BCGw1Zx32aGhpM8
license:              BSD-3-Clause
maintainer:           Dan Doel <dan.doel@gmail.com>
author:               Dan Doel
homepage:             http://code.haskell.org/~dolio/
synopsis:             Efficient conversion of values into readable byte strings.
description:          Efficient conversion of values into readable byte strings.
category:             Text
abi:                  5fec6f7384459db62910c5db3bdec32b
exposed:              True
exposed-modules:      Text.Show.ByteString
hidden-modules:
    Text.Show.ByteString.Util Text.Show.ByteString.Char
    Text.Show.ByteString.Int Text.Show.ByteString.Float
    Text.Show.ByteString.Integer

import-dirs:          /usr/lib/ghc-9.0.1/site-local/bytestring-show-0.3.5.6
library-dirs:         /usr/lib/ghc-9.0.1/site-local/bytestring-show-0.3.5.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/bytestring-show-0.3.5.6
hs-libraries:         HSbytestring-show-0.3.5.6-CyFJRb7BCGw1Zx32aGhpM8
depends:
    array-0.5.4.0 base-4.15.0.0 binary-0.8.8.0 bytestring-0.10.12.1
    containers-0.6.4.1 integer-gmp-1.1

haddock-interfaces:
    /usr/share/doc/haskell-bytestring-show/html/bytestring-show.haddock

haddock-html:         /usr/share/doc/haskell-bytestring-show/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bytestring-show-0.3.5.6-30-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bytestring-show.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bytestring-show
version:              0.3.5.6
visibility:           public
id:                   bytestring-show-0.3.5.6-8wc7HXnhGj6KX1kwwzQSh7
key:                  bytestring-show-0.3.5.6-8wc7HXnhGj6KX1kwwzQSh7
license:              BSD-3-Clause
maintainer:           Dan Doel <dan.doel@gmail.com>
author:               Dan Doel
homepage:             http://code.haskell.org/~dolio/
synopsis:             Efficient conversion of values into readable byte strings.
description:          Efficient conversion of values into readable byte strings.
category:             Text
abi:                  cb29d2d42dde47e2570092324daa9bdc
exposed:              True
exposed-modules:      Text.Show.ByteString
hidden-modules:
    Text.Show.ByteString.Util Text.Show.ByteString.Char
    Text.Show.ByteString.Int Text.Show.ByteString.Float
    Text.Show.ByteString.Integer

import-dirs:          /usr/lib/ghc-9.0.2/site-local/bytestring-show-0.3.5.6
library-dirs:         /usr/lib/ghc-9.0.2/site-local/bytestring-show-0.3.5.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/bytestring-show-0.3.5.6
hs-libraries:         HSbytestring-show-0.3.5.6-8wc7HXnhGj6KX1kwwzQSh7
depends:
    array-0.5.4.0 base-4.15.1.0 binary-0.8.8.0 bytestring-0.10.12.1
    containers-0.6.4.1 integer-gmp-1.1

haddock-interfaces:
    /usr/share/doc/haskell-bytestring-show/html/bytestring-show.haddock

haddock-html:         /usr/share/doc/haskell-bytestring-show/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
